@@ -1,10 +1,12 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-from pyaerocom import const
-import sqlite3
+import logging
 import os
+import sqlite3
+
 from pyaerocom._lowlevel_helpers import BrowseDict
 
+logger = logging.getLogger(__name__)
+
+
 class EbasSQLRequest(BrowseDict):
     """Low level dictionary like object for EBAS sqlite queries
 
@@ -47,10 +49,21 @@ class EbasSQLRequest(BrowseDict):
     ----------
     see Attributes
     """
-    def __init__(self, variables=None, start_date=None, stop_date=None,
-                 station_names=None, matrices=None, altitude_range=None,
-                 lon_range=None, lat_range=None,
-                 instrument_types=None, statistics=None, datalevel=None):
+
+    def __init__(
+        self,
+        variables=None,
+        start_date=None,
+        stop_date=None,
+        station_names=None,
+        matrices=None,
+        altitude_range=None,
+        lon_range=None,
+        lat_range=None,
+        instrument_types=None,
+        statistics=None,
+        datalevel=None,
+    ):
         self.variables = variables
         self.start_date = start_date
         self.stop_date = stop_date
@@ -68,10 +81,7 @@ class EbasSQLRequest(BrowseDict):
             if k in self:
                 self[k] = v
             else:
-                const.print_log.warning(
-                    f"Unknown EBAS SQL request key {k} (value {v})"
-                    )
-
+                logger.warning(f"Unknown EBAS SQL request key {k} (value {v})")
 
     @staticmethod
     def _var2sql(var):
@@ -82,10 +92,10 @@ class EbasSQLRequest(BrowseDict):
                 var = var[0]
 
         if isinstance(var, tuple):
-            return "{}".format(var)
+            return f"{var}"
         elif isinstance(var, str):
-            return "(\'{}\')".format(var)
-        raise ValueError('Invalid value...')
+            return f"('{var}')"
+        raise ValueError("Invalid value...")
 
     def make_file_query_str(self, distinct=True, **kwargs):
         """Wrapper for base method :func:`make_query_str`
@@ -102,10 +112,15 @@ class EbasSQLRequest(BrowseDict):
         str
             SQL file request command for current specs
         """
-        return self.make_query_str(distinct=distinct, **kwargs)
+        query = self.make_query_str(distinct=distinct, **kwargs)
+        # add an extsion to get only files that have no fraction variables in them
+        query = query.replace(
+            ";",
+            " and not exists (select * from characteristic where var_id=variable.var_id and ct_type='Fraction');",
+        )
+        return query
 
-    def make_query_str(self, what=None,
-                       distinct=True, **kwargs):
+    def make_query_str(self, what=None, distinct=True, **kwargs):
         """Translate current class state into SQL query command string
 
         Parameters
@@ -126,83 +141,81 @@ class EbasSQLRequest(BrowseDict):
         self.update(**kwargs)
         if what is None:
             what = "filename"
-        elif not isinstance(what, str): #tuple or list of parameters to be retrieved
+        elif not isinstance(what, str):  # tuple or list of parameters to be retrieved
             what = ",".join(what)
 
         if distinct:
-            req = 'select distinct {} from variable'.format(what)
+            req = f"select distinct {what} from variable"
         else:
-            req = 'select {} from variable'.format(what)
-        req += ' join station on station.station_code=variable.station_code'
+            req = f"select {what} from variable"
+        req += " join station on station.station_code=variable.station_code"
         add_cond = 0
         # add constraints from station table
         conv = self._var2sql
         if self.station_names is not None:
-
-            req += ' where station_name in {}'.format(conv(self.station_names))
+            req += f" where station_name in {conv(self.station_names)}"
             add_cond += 1
         if self.altitude_range is not None:
             low, high = self.altitude_range
-            req += ' and ' if add_cond else ' where '
-            req += ('station_altitude>{} and '
-                    'station_altitude<{}'.format(low, high))
+            req += " and " if add_cond else " where "
+            req += f"station_altitude>{low} and station_altitude<{high}"
             add_cond += 1
         if self.lon_range is not None:
             l, r = self.lon_range
-            req += ' and ' if add_cond else ' where '
-            req += ('station_longitude>{} and '
-                    'station_longitude<{}'.format(l, r))
+            req += " and " if add_cond else " where "
+            req += f"station_longitude>{l} and station_longitude<{r}"
             add_cond += 1
         if self.lat_range is not None:
             s, n = self.lat_range
-            req += ' and ' if add_cond else ' where '
-            req += ('station_latitude>{} and '
-                    'station_latitude<{}'.format(s, n))
+            req += " and " if add_cond else " where "
+            req += f"station_latitude>{s} and station_latitude<{n}"
             add_cond += 1
         if self.instrument_types is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'instr_type in {}'.format(conv(self.instrument_types))
+            req += " and " if add_cond else " where "
+            req += f"instr_type in {conv(self.instrument_types)}"
             add_cond += 1
         # add constraints from variable table
         if self.variables is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'comp_name in {}'.format(conv(self.variables))
+            req += " and " if add_cond else " where "
+            req += f"comp_name in {conv(self.variables)}"
             add_cond += 1
         if self.stop_date is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'first_end < \'{}\''.format(self.stop_date)
+            req += " and " if add_cond else " where "
+            req += f"first_end < '{self.stop_date}'"
             add_cond += 1
         if self.start_date is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'last_start > \'{}\''.format(self.start_date)
+            req += " and " if add_cond else " where "
+            req += f"last_start > '{self.start_date}'"
             add_cond += 1
         if self.matrices is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'matrix in {}'.format(conv(self.matrices))
+            req += " and " if add_cond else " where "
+            req += f"matrix in {conv(self.matrices)}"
             add_cond += 1
         if self.statistics is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'statistics in {}'.format(conv(self.statistics))
+            req += " and " if add_cond else " where "
+            req += f"statistics in {conv(self.statistics)}"
             add_cond += 1
         if self.datalevel is not None:
-            req += ' and ' if add_cond else ' where '
-            req += 'datalevel={}'.format(self.datalevel)
+            req += " and " if add_cond else " where "
+            req += f"datalevel={self.datalevel}"
             add_cond += 1
-        return (req + ";")
+        return req + ";"
 
     def __str__(self):
-        head = "Pyaerocom {}".format(type(self).__name__)
-        s = "\n{}\n{}".format(head, len(head)*"-")
+        head = f"Pyaerocom {type(self).__name__}"
+        s = f"\n{head}\n{len(head) * '-'}"
         for k, v in self.items():
-            s += "\n{}: {}".format(k, v)
-        s += '\nFilename request string:\n{}'.format(self.make_file_query_str())
+            s += f"\n{k}: {v}"
+        s += f"\nFilename request string:\n{self.make_file_query_str()}"
         return s
 
-class EbasFileIndex(object):
+
+class EbasFileIndex:
     """EBAS SQLite I/O interface
 
     Takes care of connection to database and execution of requests
     """
+
     def __init__(self, database=None):
         self._database = database
 
@@ -211,14 +224,16 @@ class EbasFileIndex(object):
         """Path to ebas_file_index.sqlite3 file"""
         db = self._database
         if db is None or not os.path.exists(db):
-            raise AttributeError('EBAS SQLite database file could not be '
-                                 'located but is needed in EbasFileIndex class')
+            raise AttributeError(
+                "EBAS SQLite database file could not be "
+                "located but is needed in EbasFileIndex class"
+            )
         return db
 
     @property
     def ALL_STATION_NAMES(self):
         """List of all available station names in database"""
-        names = self.execute_request('select distinct station_name from station')
+        names = self.execute_request("select distinct station_name from station")
         return [x[0] for x in names]
 
     @property
@@ -231,7 +246,7 @@ class EbasFileIndex(object):
         :attr:`STATION_NAMES`, i.e. the lists should not be linked to each
         other
         """
-        names = self.execute_request('select distinct station_code from station')
+        names = self.execute_request("select distinct station_code from station")
         return [x[0] for x in names]
 
     @property
@@ -241,30 +256,33 @@ class EbasFileIndex(object):
         For more info see `here <https://ebas-submit.nilu.no/Submit-Data/
         Data-Reporting/Comments/Generic-metadata-comments/Statistics>`__
         """
-        names = self.execute_request('select distinct statistics from variable')
+        names = self.execute_request("select distinct statistics from variable")
         return [x[0] for x in names]
 
     @property
     def ALL_VARIABLES(self):
         """List of all variables available"""
-        names = self.execute_request('select distinct comp_name from variable')
+        names = self.execute_request("select distinct comp_name from variable")
         return [x[0] for x in names]
 
     @property
     def ALL_MATRICES(self):
         """List of all matrix values available"""
-        names = self.execute_request('select distinct matrix from variable')
+        names = self.execute_request("select distinct matrix from variable")
         return [x[0] for x in names]
 
     @property
     def ALL_INSTRUMENTS(self):
         """List of all variables available"""
-        names = self.execute_request('select distinct instr_type from variable')
+        names = self.execute_request("select distinct instr_type from variable")
         return [x[0] for x in names]
 
     def get_table_names(self):
         """Get all table names in SQLite database file"""
-        return [x[0] for x in self.execute_request("SELECT name FROM sqlite_master WHERE type='table';")]
+        return [
+            x[0]
+            for x in self.execute_request("SELECT name FROM sqlite_master WHERE type='table';")
+        ]
 
     def get_table_columns(self, table_name):
         """Get all columns of a table in SQLite database file"""
@@ -274,7 +292,7 @@ class EbasFileIndex(object):
             cur.execute(req)
             return [f[0] for f in cur.description]
 
-    def execute_request(self, request):
+    def execute_request(self, request, file_request=False):
         """Connect to database and retrieve data for input request
 
         Parameters
@@ -291,11 +309,19 @@ class EbasFileIndex(object):
             :func:`make_query_str` using argument ``what``)
 
         """
-        if isinstance(request, EbasSQLRequest):
-            request = request.make_query_str()
+        if isinstance(request, str):
+            sql_str = request
+        elif isinstance(request, EbasSQLRequest):
+            if not file_request:
+                sql_str = request.make_query_str()
+            else:
+                sql_str = request.make_file_query_str()
+        else:
+            raise ValueError(f"Unsupported request type {type(request)}")
+
         with sqlite3.connect(self.database) as con:
             cur = con.cursor()
-            cur.execute(request)
+            cur.execute(sql_str)
             return [f for f in cur.fetchall()]
 
     def get_file_names(self, request):
@@ -311,4 +337,4 @@ class EbasFileIndex(object):
         list
             list of file paths that match the request
         """
-        return [f[0] for f in self.execute_request(request)]
\ No newline at end of file
+        return [f[0] for f in self.execute_request(request, file_request=True)]
